Index: wp-admin/includes/plugin.php
===================================================================
--- wp-admin/includes/plugin.php	(revision 17967)
+++ wp-admin/includes/plugin.php	(working copy)
@@ -1063,6 +1063,10 @@
  * The function which is hooked in to handle the output of the page must check
  * that the user has the required capability as well.
  *
+ * This sub menu page is bundled with some help documentation that can be overriden by specific themes.
+ *
+ * @see add_contextual_help()
+ *
  * @param string $page_title The text to be displayed in the title tags of the page when the menu is selected
  * @param string $menu_title The text to be used for the menu
  * @param string $capability The capability required for this menu to be displayed to the user.
@@ -1072,7 +1076,14 @@
  * @return string The resulting page's hook_suffix
  */
 function add_theme_page( $page_title, $menu_title, $capability, $menu_slug, $function = '' ) {
-	return add_submenu_page( 'themes.php', $page_title, $menu_title, $capability, $menu_slug, $function );
+	$theme_page = add_submenu_page( 'themes.php', $page_title, $menu_title, $capability, $menu_slug, $function );
+	add_contextual_help( $theme_page,
+		'<p>' . __( 'Theme options allow you to customize certain settings available for an individual theme, such as its look and feel.' ) . '</p>' .
+		'<p><strong>' . __( 'For more information:' ) . '</strong></p>' .
+		'<p>' . __( '<a href="http://codex.wordpress.org/Appearance_Theme_Options_Screen" target="_blank">Documentation on Theme Options</a>' ) . '</p>' .
+		'<p>' . __( '<a href="http://wordpress.org/support/" target="_blank">Support Forums</a>' ) . '</p>'
+	);
+	return $theme_page;
 }
 
 /**
Index: wp-content/themes/twentyeleven/inc/theme-options.php
===================================================================
--- wp-content/themes/twentyeleven/inc/theme-options.php	(revision 17967)
+++ wp-content/themes/twentyeleven/inc/theme-options.php	(working copy)
@@ -55,20 +55,34 @@
 add_action( 'admin_init', 'twentyeleven_theme_options_init' );
 
 /**
  * Add our theme options page to the admin menu.
  *
  * This function is attached to the admin_menu action hook.
  *
  * @since Twenty Eleven 1.0
  */
 function twentyeleven_theme_options_add_page() {
-	add_theme_page(
+	$theme_page = add_theme_page(
 		__( 'Theme Options', 'twentyeleven' ), // Name of page
 		__( 'Theme Options', 'twentyeleven' ), // Label in menu
 		'edit_theme_options',                  // Capability required
 		'theme_options',                       // Menu slug, used to uniquely identify the page
 		'theme_options_render_page'            // Function that renders the options page
 	);
+	$help = '<p>' . __( 'This Theme Options screen, as enabled by your theme, Twenty Eleven, allows you to change some settings regarding the theme&#8217;s color and layout.') . '</p>' .
+			'<p>' . __( 'You can toggle between Light or Dark text areas for your site in Color Scheme, with contrasting letters. Colors could be further changed or examined in the theme&#8217;s CSS via Appearance > Editor. The color for links can be set to specific values or using a color wheel by clicking on the color patch or "Select a Color" button.' ) . '</p>' .
+			'<p>' . __( 'There are three options for the theme&#8217;s layout (each containing the same header):' ) . '</p>' .
+			'<ol>' .
+				'<li>' . __( 'Main content on left, sidebar on right' ) . '</li>' .
+				'<li>' . __( 'Main content on right, sidebar on left' ) . '</li>' .
+				'<li>' . __( 'Main content spans the entire site&#8217;s width, no sidebar' ) . '</li>' .
+			'</ol>' .
+			'<p>' . __( 'Remember to click "Save Changes" to save any changes you have made to the theme&#8217;s options.' ) . '</p>' .
+			'<p><strong>' . __('For more information:') . '</strong></p>' .
+			'<p>' . __( '<a href="http://codex.wordpress.org/Appearance_Theme_Options_Screen" target="_blank">Documentation on Theme Options</a>' ) . '</p>' .
+			'<p>' . __( '<a href="http://wordpress.org/support/" target="_blank">Support Forums</a>' ) . '</p>';
+
+	add_contextual_help( $theme_page, $help );
 }
 add_action( 'admin_menu', 'twentyeleven_theme_options_add_page' );
 
@@ -113,7 +127,7 @@
 		),
 		'content' => array(
 			'value' => 'content',
-			'label' => __( 'One-column, no Sidebar', 'twentyeleven' ),
+			'label' => __( 'One-column, no sidebar', 'twentyeleven' ),
 			'thumbnail' => get_template_directory_uri() . '/inc/images/content.png',
 		),
 	);
@@ -55,20 +55,34 @@
 
 /**
- * Add our theme options page to the admin menu.
+ * Add our theme options page to the admin menu, including some help documentation.
  *
  * This function is attached to the admin_menu action hook.
